@@ -2228,11 +2228,11 @@ Init_xmlparser()
 #endif
 #ifdef XML_DTD
   rb_define_const(cXMLParser, "PARAM_ENTITY_PARSING_NEVER",
-		  XML_PARAM_ENTITY_PARSING_NEVER);
+		  INT2FIX(XML_PARAM_ENTITY_PARSING_NEVER));
   rb_define_const(cXMLParser, "PARAM_ENTITY_PARSING_UNLESS_STANDALONE",
-		  XML_PARAM_ENTITY_PARSING_UNLESS_STANDALONE);
+		  INT2FIX(XML_PARAM_ENTITY_PARSING_UNLESS_STANDALONE));
   rb_define_const(cXMLParser, "PARAM_ENTITY_PARSING_ALWAYS",
-		  XML_PARAM_ENTITY_PARSING_ALWAYS);
+		  INT2FIX(XML_PARAM_ENTITY_PARSING_ALWAYS));
 #endif
 #ifdef HAVE_XML_SETDOCTYPEDECLHANDLER
   DEFINE_EVENT_CODE(cXMLParser, START_DOCTYPE_DECL);
